hotspot/src/share/vm/ci/ciEnv.hpp
changeset 10503 04b74421bdea
parent 10008 d84de97ad847
child 10508 233d2e7c462d
--- a/hotspot/src/share/vm/ci/ciEnv.hpp	Sat Aug 27 00:23:47 2011 -0700
+++ b/hotspot/src/share/vm/ci/ciEnv.hpp	Mon Aug 29 05:07:35 2011 -0700
@@ -247,9 +247,9 @@
   // Is this thread currently in the VM state?
   static bool is_in_vm();
 
-  // Helper routine for determining the validity of a compilation
-  // with respect to concurrent class loading.
-  void check_for_system_dictionary_modification(ciMethod* target);
+  // Helper routine for determining the validity of a compilation with
+  // respect to method dependencies (e.g. concurrent class loading).
+  void validate_compile_task_dependencies(ciMethod* target);
 
 public:
   enum {